/**
 * The Abiquo Platform
 * Cloud management application for hybrid clouds
 * Copyright (C) 2008 - Abiquo Holdings S.L.
 *
 * This application is free software; you can redistribute it and/or
 * modify it under the terms of the GNU LESSER GENERAL PUBLIC
 * LICENSE as published by the Free Software Foundation under
 * version 3 of the License
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * LESSER GENERAL PUBLIC LICENSE v.3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.abiquo.ssm.exception;

/**
 * Exception thrown by the storage plugins.
 * 
 * @author Ignasi Barrera
 */
public class PluginException extends Exception
{
    /** Serial UID. */
    private static final long serialVersionUID = 1L;

    /** The type of the error. */
    private PluginError errorType;

    /**
     * Creates a new <code>PluginException</code>.
     * 
     * @param cause The exception cause.
     */
    public PluginException(final String message)
    {
        super(message);
        errorType = PluginError.UNKNOWN;
    }

    /**
     * Creates a new <code>PluginException</code>.
     * 
     * @param errorType The type of the error.
     * @param cause The exception cause.
     */
    public PluginException(final PluginError errorType, final String message)
    {
        super(message);
        this.errorType = errorType;
    }

    /**
     * Creates a new <code>PluginException</code>.
     * 
     * @param cause The exception cause.
     */
    public PluginException(final Throwable cause)
    {
        super(cause);
        errorType = PluginError.UNKNOWN;
    }

    /**
     * Creates a new <code>PluginException</code>.
     * 
     * @param errorType The type of the error.
     * @param cause The exception cause.
     */
    public PluginException(final PluginError errorType, final Throwable cause)
    {
        super(cause);
        this.errorType = errorType;
    }

    /**
     * Creates a new <code>PluginException</code>.
     * 
     * @param message The exception message.
     * @param cause The exception cause.
     */
    public PluginException(final String message, final Throwable cause)
    {
        super(message, cause);
        errorType = PluginError.UNKNOWN;
    }

    /**
     * Creates a new <code>PluginException</code>.
     * 
     * @param errorType The type of the error.
     * @param message The exception message.
     * @param cause The exception cause.
     */
    public PluginException(final PluginError errorType, final String message, final Throwable cause)
    {
        super(message, cause);
        this.errorType = errorType;
    }

    // Getters and setters

    public PluginError getErrorType()
    {
        return errorType;
    }

    public void setErrorType(final PluginError errorType)
    {
        this.errorType = errorType;
    }
}
