/**
 * The Abiquo Platform
 * Cloud management application for hybrid clouds
 * Copyright (C) 2008 - Abiquo Holdings S.L.
 *
 * This application is free software; you can redistribute it and/or
 * modify it under the terms of the GNU LESSER GENERAL PUBLIC
 * LICENSE as published by the Free Software Foundation under
 * version 3 of the License
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * LESSER GENERAL PUBLIC LICENSE v.3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.abiquo.ssm.model.metadata;

import java.util.ArrayList;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;

/**
 * Metadata to describe the storage plugin.
 * 
 * @author Ignasi Barrera
 */
@XmlRootElement(name = "metadata")
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(propOrder = {"type", "defaultManagementPort", "defaultIscsiPort",
"requiresAuthentication", "supportedOperations"})
public class StoragePluginMetadata
{
    /** A unique name identifying the storage device type (e.g. NETAPP, LVM, etc). */
    private String type;

    /** Flag indicating if the API requires authentication. */
    private boolean requiresAuthentication;

    /** The default port for the management API. */
    private int defaultManagementPort;

    /** The default iscsi port for the device. */
    private int defaultIscsiPort;

    /** The operations currently supported for the device. */
    @XmlElementWrapper(name = "supports")
    @XmlElement(name = "op")
    private List<StorageOp> supportedOperations = new ArrayList<StorageOp>();

    /**
     * Checks if the current plugin supports the given operation.
     * 
     * @param op The operation to check.
     * @return Boolean indicating if the current plugin supports the given operation.
     */
    public boolean supports(final StorageOp op)
    {
        return supportedOperations.contains(op);
    }

    public String getType()
    {
        return type;
    }

    public void setType(final String type)
    {
        this.type = type;
    }

    public boolean isRequiresAuthentication()
    {
        return requiresAuthentication;
    }

    public void setRequiresAuthentication(final boolean requiresAuthentication)
    {
        this.requiresAuthentication = requiresAuthentication;
    }

    public int getDefaultManagementPort()
    {
        return defaultManagementPort;
    }

    public void setDefaultManagementPort(final int defaultManagementPort)
    {
        this.defaultManagementPort = defaultManagementPort;
    }

    public int getDefaultIscsiPort()
    {
        return defaultIscsiPort;
    }

    public void setDefaultIscsiPort(final int defaultIscsiPort)
    {
        this.defaultIscsiPort = defaultIscsiPort;
    }

    public List<StorageOp> getSupportedOperations()
    {
        return supportedOperations;
    }

    public void setSupportedOperations(final List<StorageOp> supportedOperations)
    {
        this.supportedOperations = supportedOperations;
    }

}
