/**
 * The Abiquo Platform
 * Cloud management application for hybrid clouds
 * Copyright (C) 2008 - Abiquo Holdings S.L.
 *
 * This application is free software; you can redistribute it and/or
 * modify it under the terms of the GNU LESSER GENERAL PUBLIC
 * LICENSE as published by the Free Software Foundation under
 * version 3 of the License
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * LESSER GENERAL PUBLIC LICENSE v.3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
package com.abiquo.ssm.plugin.annotations;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

/**
 * Describes a storage plugin.
 * 
 * @author Ignasi Barrera
 */
@Retention(RetentionPolicy.RUNTIME)
@Target(ElementType.TYPE)
public @interface Plugin
{
    /**
     * The type of the storage device that the plugin will manage.
     * <p>
     * This type should be a unique string identifying the storage plugin. For example:
     * <code>LVM</code>, <code>NETAPP</code>.
     */
    String type();

    /**
     * Boolean indicating if the storage device requires authentication.
     */
    boolean requiresAuthentication() default true;

    /**
     * The default port used for ISCSI connections to the device.
     * <p>
     * This is the port that the hypervisors will use to access the volumes attached to the virtual
     * machines.
     */
    int defaultIscsiPort() default 3260;

    /**
     * The default management port.
     * <p>
     * This is the port that will be used by Abiquo to connect to the management API of the storage
     * device.
     */
    int defaultManagementPort();

}
